[llvm-commits] [llvm] r76679 - in /llvm/trunk: include/llvm/CodeGen/MachineConstantPool.h lib/CodeGen/MachineFunction.cpp lib/Target/ARM/ARMConstantPoolValue.h

Chris Lattner sabre at nondot.org
Tue Jul 21 16:36:01 PDT 2009


Author: lattner
Date: Tue Jul 21 18:36:01 2009
New Revision: 76679

URL: http://llvm.org/viewvc/llvm-project?rev=76679&view=rev
Log:
no really, I can spell!

Modified:
    llvm/trunk/include/llvm/CodeGen/MachineConstantPool.h
    llvm/trunk/lib/CodeGen/MachineFunction.cpp
    llvm/trunk/lib/Target/ARM/ARMConstantPoolValue.h

Modified: llvm/trunk/include/llvm/CodeGen/MachineConstantPool.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/include/llvm/CodeGen/MachineConstantPool.h?rev=76679&r1=76678&r2=76679&view=diff

==============================================================================
--- llvm/trunk/lib/CodeGen/MachineFunction.cpp (original)
+++ llvm/trunk/lib/CodeGen/MachineFunction.cpp Tue Jul 21 18:36:01 2009
@@ -544,9 +544,9 @@
 }
 
 
-unsigned MachineConstantPoolEntry::getRelocatationInfo() const {
+unsigned MachineConstantPoolEntry::getRelocationInfo() const {
   if (isMachineConstantPoolEntry())
-    return Val.MachineCPVal->getRelocatationInfo();
+    return Val.MachineCPVal->getRelocationInfo();
   
   // FIXME: This API sucks.
   

Modified: llvm/trunk/lib/Target/ARM/ARMConstantPoolValue.h
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/Target/ARM/ARMConstantPoolValue.h?rev=76679&r1=76678&r2=76679&view=diff

==============================================================================
--- llvm/trunk/lib/Target/ARM/ARMConstantPoolValue.h (original)
+++ llvm/trunk/lib/Target/ARM/ARMConstantPoolValue.h Tue Jul 21 18:36:01 2009
@@ -65,7 +65,7 @@
   bool isStub() const { return Kind == ARMCP::CPStub; }
   unsigned char getPCAdjustment() const { return PCAdjust; }
 
-  virtual unsigned getRelocatationInfo() const {
+  virtual unsigned getRelocationInfo() const {
     // FIXME: This is conservatively claiming that these entries require a
     // relocation, we may be able to do better than this.
     return 2;





More information about the llvm-commits mailing list
--- llvm/trunk/include/llvm/CodeGen/MachineConstantPool.h (original)
+++ llvm/trunk/include/llvm/CodeGen/MachineConstantPool.h Tue Jul 21 18:36:01 2009
@@ -44,7 +44,7 @@
   const Type *getType() const { return Ty; }
 
   
   /// getRelocatationInfo - This method classifies the entry according to
   /// whether or not it may generate a relocation entry.  This must be
   /// conservative, so if it might codegen to a relocatable entry, it should say
   /// so.  The return values are:
@@ -55,7 +55,7 @@
   ///     resolvable by the static linker, so the dynamic linker will never see
   ///     them.
   ///  2: This entry may have arbitrary relocations. 
-  virtual unsigned getRelocatationInfo() const = 0;
+  virtual unsigned getRelocationInfo() const = 0;
   
   virtual int getExistingMachineCPValue(MachineConstantPool *CP,
                                         unsigned Alignment) = 0;
@@ -109,7 +109,7 @@
 
   const Type *getType() const;
   
   /// getRelocatationInfo - This method classifies the entry according to
   /// whether or not it may generate a relocation entry.  This must be
   /// conservative, so if it might codegen to a relocatable entry, it should say
   /// so.  The return values are:
@@ -120,7 +120,7 @@
   ///     resolvable by the static linker, so the dynamic linker will never see
   ///     them.
   ///  2: This entry may have arbitrary relocations. 
-  unsigned getRelocatationInfo() const;
+  unsigned getRelocationInfo() const;
 };
   
 /// The MachineConstantPool class keeps track of constants referenced by a
@@ -44,7 +44,7 @@
 
   
-  /// getRelocatationInfo - This method classifies the entry according to
+  /// getRelocationInfo - This method classifies the entry according to
   /// whether or not it may generate a relocation entry.  This must be
   /// conservative, so if it might codegen to a relocatable entry, it should say
@@ -109,7 +109,7 @@
   const Type *getType() const;
   
-  /// getRelocatationInfo - This method classifies the entry according to
+  /// getRelocationInfo - This method classifies the entry according to
   /// whether or not it may generate a relocation entry.  This must be
   /// conservative, so if it might codegen to a relocatable entry, it should say

Modified: llvm/trunk/lib/CodeGen/MachineFunction.cpp
URL: http://llvm.org/viewvc/llvm-project/llvm/trunk/lib/CodeGen/MachineFunction.cpp?rev=76679&r1=76678&r2=76679&view=diff

==============================================================================